@@ -24,13 +24,13 @@
   (lambda _
     (load-extension "libguile-nomad" "init_guile_nomad_lib"))
   (lambda (key . param)
-    (load-extension "/home/mrosset/local/libexec/nomad/libguile-nomad.so"
+    (load-extension "/usr/local/libexec/nomad/libguile-nomad.so"
                     "init_guile_nomad_lib")))
 
 (define (dynamic-path)
   (if (libguile-nomad?)
       "libguile-nomad"
-      "/home/mrosset/local/libexec/nomad/libguile-nomad.so"))
+      "/usr/local/libexec/nomad/libguile-nomad.so"))
 
 ;; Local Variables:
 ;; mode: scheme
