@@ -6,11 +6,15 @@
             option-client
             option-listen
             option-url
+            option-quick
             ))
 
 (define option-spec
   '((listen  (value #t))
+    (gapplication-app-id  (value "org.gnu.nomad"))
+    (help-all (value #f))
     (client  (single-char #\c) (value #f))
+    (quick   (single-char #\Q) (value #f))
     (app-id  (value #t))
     (version (single-char #\v) (value #f))
     (help    (single-char #\h) (value #f))))
@@ -18,6 +22,9 @@
 (define (get-option key options default)
   (option-ref (getopt-long options option-spec) key default))
 
+(define (option-quick options)
+  (get-option 'quick options #f))
+
 (define (option-app-id options)
   (get-option 'app-id options "org.gnu.nomad"))
 
